/**
 * Copyright ou © ou Copr. Ministère de l'Europe et des Affaires étrangères (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * Ce logiciel est un programme informatique servant à faciliter la création
 * d'applications Web conformément aux référentiels généraux français : RGI, RGS et RGAA
 * <p/>
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 * <p/>
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * <p/>
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 * <p/>
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 * <p/>
 * <p/>
 * Copyright or © or Copr. Ministry for Europe and Foreign Affairs (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * This software is a computer program whose purpose is to facilitate creation of
 * web application in accordance with french general repositories : RGI, RGS and RGAA.
 * <p/>
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * <p/>
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * <p/>
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * <p/>
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */

/**
 * hornet-js-core - Ensemble des composants qui forment le coeur de hornet-js
 *
 * @author MEAE - Ministère de l'Europe et des Affaires étrangères
 * @version v5.2.2
 * @link git+https://github.com/diplomatiegouvfr/hornet-js.git
 * @license CECILL-2.1
 */

import { Utils } from "hornet-js-utils";
import { Logger } from "hornet-js-utils/src/logger";
import * as path from "path";

import { Class } from "hornet-js-utils/src/typescript-utils";
import { ServerConfiguration }  from "hornet-js-core/src/server-conf";
import ErrorObject = ajv.ErrorObject;
import { Timer }  from "hornet-js-core/src/timers/timer";

const isEnvProduction: boolean = (process.env[ "NODE_ENV" ] === "production");

function isSecurityEnabled(envProduction: boolean, logger): boolean {
    let enabled: boolean = false;
    if (Utils.config.get("security")) {
        if (Utils.config.get("security.enabled") || envProduction) {
            enabled = true;
            logger.trace("SECURITY MIDDLEWARE CONFIGURATION :  Configuration de la sécurité...");
        } else {
            logger.warn("SECURITY MIDDLEWARE CONFIGURATION : La sécurité est désactivé!!!");
        }
    } else {
        logger.warn("SECURITY MIDDLEWARE CONFIGURATION : La sécurité n'est pas configurée!!!");
    }
    return enabled;
}

function checkSecurityConfiguration(key: string, enabledKey: boolean, middlewareName: string, logger): boolean {
    let enabled: boolean = false;
    if (Utils.config.has(key)) {
        if (enabledKey) {
            key = key + ".enabled";
        }

        if (Utils.config.getOrDefault(key, true)) {
            logger.debug("SECURITY MIDDLEWARE CONFIGURATION : ajout du middleware " + middlewareName);
            enabled = true;
        } else {
            logger.warn("SECURITY MIDDLEWARE CONFIGURATION : Le middleware " + middlewareName + " n'est pas activé");
        }
    } else {
        logger.warn("SECURITY MIDDLEWARE CONFIGURATION : Le middleware " + middlewareName + " n'est pas configuré");
    }
    return enabled;
}

function sanitizeErrorThrownInDomain(error) {
    if (error) {
        delete error[ "error@context" ];
        delete error[ "domain" ];
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
/**
 * Classe abstraite de gestion d'un middleware dans une application Hornet
 * Cette classe doit être héritée par chaque middleware
 *
 * Attention : la classe héritant de AbstractHornetMiddleware doit définir le constructeur suivant :
 *          constructor() {
 *              [...]
 *              super(appConfig, PREFIX_OPTIONNEL, FN_OPTIONNEL);
 *              [...]
 *          }
 *
 * > Par défaut, la fonction "insertMiddleware(app)" utilise le PREFIX et FN fournis : app.use(PREFIX, FN)
 *
 * > Pour des cas particuliers, il est possible de surcharger cette méthode pour ajouter autant de middlewares qu'on veut :
 *      public insertMiddleware(app) {
 *          app.use("/exemple", (req, res, next) => { [ ... ] });
 *          app.use((req, res, next) => { .... });
 *          ...
 *      }
 */
export class AbstractHornetMiddleware {
    static APP_CONFIG: ServerConfiguration;
    protected prefix: string;
    protected middlewareFunction: ErrorRequestHandler | RequestHandler;
    protected config: ServerConfiguration;

    /**
     * Constructeur
     *
     * @param middlewareFunction
     * @param prefix
     * @param config server configuration
     */
    constructor(middlewareFunction?: ErrorRequestHandler | RequestHandler, prefix?: string, config?: ServerConfiguration) {
        this.prefix = prefix;
        this.middlewareFunction = middlewareFunction;
        this.config = config;
    }

    /**
     * Méthode appelée automatiquement lors de l'initialisation du serveur afin d'ajouter un middleware
     * @param app
     */
    public insertMiddleware(app: express.Express) {

        if (this.prefix !== null && this.prefix !== undefined) {
            app.use(this.prefix, this.middlewareFunction);
        } else {
            app.use(this.middlewareFunction);
        }
    }
}

export class AbstractHornetSubMiddleware extends AbstractHornetMiddleware {

    public insertRouterMiddleware(router: express.Router) {
        if (this.prefix !== null && this.prefix !== undefined) {
            router.use(this.prefix, this.middlewareFunction as any);
        } else {
            router.use(this.middlewareFunction as any);
        }
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      HornetContextInitializerMiddleware
// ------------------------------------------------------------------------------------------------------------------- //

import { RouteType }  from "hornet-js-core/src/routes/abstract-routes";

export class HornetContextInitializerMiddleware extends AbstractHornetMiddleware {
    constructor() {
        const callbacksStorage = Utils.getContinuationStorage();
        const dataPathPrefix = Utils.buildContextPath(
            Utils.config.getOrDefault("fullSpa.name", AbstractHornetMiddleware.APP_CONFIG.routesDataContext));
        super((req, res, next) => {
            callbacksStorage.bindEmitter(req);
            callbacksStorage.bindEmitter(res);

            callbacksStorage.run(() => {
                callbacksStorage.set("hornet.request", req);
                callbacksStorage.set("hornet.response", res);
                callbacksStorage.set("hornet.routeType", parseUrl.original(req).pathname.indexOf(dataPathPrefix) === 0
                    ? RouteType.DATA
                    : RouteType.PAGE);

                const currentUrl = parseUrl.original(req).pathname;
                const relativePathname = currentUrl.replace(Utils.getContextPath(), "");
                callbacksStorage.set("hornet.routePath", relativePathname);
                callbacksStorage.set("hornet.currentUrl", currentUrl);
                next();
            });
        });
    }
}

export class HornetContextInitializerSubMiddleware extends AbstractHornetSubMiddleware {
    constructor(config: ServerConfiguration, prefix) {
        const dataPathPrefix: string = Utils.buildContextPath("/" + prefix + (config
            || AbstractHornetMiddleware.APP_CONFIG).routesDataContext);
        super((req, res, next) => {

            Utils.setCls("hornet.routeType", parseUrl.original(req).pathname.indexOf(dataPathPrefix) === 0
                ? RouteType.DATA
                : RouteType.PAGE);
            next();
        },    null, config);
    }

}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      LoggerTIDMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
const uuid = require("uuid");

export class LoggerTIDMiddleware extends AbstractHornetMiddleware {
    
    constructor() {
        super((req, res, next) => {
            Utils.setCls("hornet.tid", uuid.v4().substr(0, 8));
            Timer.startTimer(Timer.TIMER_REQUEST);
            Timer.startTimer(Timer.TIMER_SERVER_HTTP);
            next();
        });
    }

}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      LoggerUserMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
export class LoggerUserMiddleware extends AbstractHornetMiddleware {
    protected static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.LoggerUserMiddleware");

    constructor() {
        super((req, res, next) => {
            Utils.setCls("hornet.user", req.user);
            next();
        });
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      WelcomePageRedirectMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
const parseUrl = require("parseurl");

export class WelcomePageRedirectMiddleware extends AbstractHornetMiddleware {
    protected static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.WelcomePageRedirectMiddleware");

    constructor() {
        const contextPath = Utils.buildContextPath("/").replace(/(^.*)([^\/]+)\/+$/g, "$1$2");
        const welcomePage = Utils.buildContextPath(Utils.appSharedProps.get("welcomePageUrl")).replace(/(^.*)([^\/]+)\/+$/g, "$1$2");

        super((req, res, next) => {
            const pathname = parseUrl.original(req).pathname.replace(/(^.*)([^\/]+)\/+$/g, "$1$2");
            if (pathname === contextPath && welcomePage !== contextPath) {
                return res.redirect(welcomePage);
            } else {
                next();
            }
        });
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      WithoutSlashPageRedirectMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
export class WithoutSlashPageRedirectMiddleware extends AbstractHornetMiddleware {
    constructor() {
        const contextPath = Utils.getContextPath();
        super((req, res, next) => {
            const pathname = parseUrl.original(req).pathname;
            if (pathname === contextPath) {
                return res.redirect(contextPath + "/");
            } else {
                next();
            }
        });
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      StaticNodeHttpHeaderMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
export class StaticNodeHttpHeaderMiddleware extends AbstractHornetMiddleware {
    protected static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.StaticNodeHttpHeaderMiddleware");

    constructor() {
        const staticUrl = Utils.buildStaticPath("/").replace(Utils.getContextPath(), "");

        super((req, res, next) => {
            res.setHeader("X-Static-From", "app");
            next();
        },    staticUrl);
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      StaticPathMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
import * as express from "express";

export class StaticPathMiddleware extends AbstractHornetMiddleware {
    protected static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.StaticPathMiddleware");

    constructor() {
        const appConfig = AbstractHornetMiddleware.APP_CONFIG;
        const staticPath = path.join(appConfig.serverDir, appConfig.staticPath);

        const staticUrl = Utils.buildStaticPath("/").replace(Utils.getContextPath(), "");

        StaticPathMiddleware.logger.trace("Emplacement des ressources statiques '" + staticUrl + "' :", staticPath);

        super(express.static(staticPath, (<any>{ fallthrough: false })), staticUrl);
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      StaticPathErrorMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
export class StaticPathErrorMiddleware extends AbstractHornetMiddleware {
    protected static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.StaticPathErrorMiddleware");

    constructor() {

        const staticUrl = Utils.buildStaticPath("/").replace(Utils.getContextPath(), "");

        super((err, req, res, next) => {
            res.status(404).send("Resource not found").end();
            StaticPathErrorMiddleware.logger.error("Ressource statique non trouvée", err);
        },    staticUrl);
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      BodyParserJsonMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
import * as bodyParser from "body-parser";

export class BodyParserJsonMiddleware extends AbstractHornetMiddleware {
    constructor() {
        super(bodyParser.json({ limit: Utils.config.getOrDefault("server.bodyParserLimit", "50mb") }));
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      BodyParserUrlEncodedMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
export class BodyParserUrlEncodedMiddleware extends AbstractHornetMiddleware {
    constructor() {
        super(bodyParser.urlencoded({ // to support URL-encoded bodies
            extended: true,
            limit: Utils.config.getOrDefault("server.bodyParserLimit", "50mb"),
        }));
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      SessionMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
import { SessionManager }  from "hornet-js-core/src/session/session-manager";

export class SessionMiddleware extends AbstractHornetMiddleware {
    constructor() {
        const sessionConfiguration = {
            trustProxy: Utils.config.getOrDefault("server.trustProxy", false),
            store: AbstractHornetMiddleware.APP_CONFIG.sessionStore || null,
            // secret: Utils.config.get('cookie.secret'),
            secret: null,
            cookie: {
                route: Utils.config.getOrDefault("server.route", null),
                domain: Utils.config.getOrDefault("cookie.domain", null),
                path: Utils.config.getOrDefault("cookie.path", Utils.buildContextPath("/")),
                httpOnly: Utils.config.getOrDefault("cookie.httpOnly", true),
                secure: (isEnvProduction && Utils.config.getOrDefault("cookie.secure", false)),
                maxAge: Utils.config.getOrDefault("cookie.maxAge", undefined),
            },
            sessionTimeout: Utils.config.getOrDefault("server.sessionTimeout", 1800000),
            alwaysSetCookie: Utils.config.getOrDefault("cookie.alwaysSetCookie", false),
            saveUnmodifiedSession: null, // laisse le session-manager décider en fonction du type de store
        };

        super(SessionManager.middleware(sessionConfiguration));
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      MulterMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
import multer = require("multer");
import { CustomStoreEngine }  from "hornet-js-core/src/upload/custom-store-engine";

export class MulterMiddleware extends AbstractHornetMiddleware {

    /**
     * Parametrage static de middleware multer
     */
    static option: multer.Options = undefined;

    static defaultOption: multer.Options = {
        storage: Utils.config.getOrDefault("server.uploadAntivirus", false) ?
            new CustomStoreEngine()
            : multer.memoryStorage(),
        limits: {
            fileSize: Utils.config.getOrDefault("server.uploadFileSize", 10000),
        },
    };

    constructor() {
        const option: multer.Options = MulterMiddleware.defaultOption;
        if (MulterMiddleware.option) {
            _.merge(option, MulterMiddleware.option);
        }
        super(multer(option).any());
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      SecurityMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
import hpp = require("hpp");

const helmet = require("helmet");

export class SecurityMiddleware extends AbstractHornetMiddleware {
    protected static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.SecurityMiddleware");

    public insertMiddleware(app) {
        if (isSecurityEnabled(isEnvProduction, SecurityMiddleware.logger)) {
            // Enlève le header 'x-powered-by' pour éviter de montrer que le site est généré par express
            app.disable("x-powered-by");

            this.hppConfiguration(app);
            this.ieNoOpenConfiguration(app);
            this.noSniffConfiguration(app);
            this.cspConfiguration(app);
            this.frameguardConfiguration(app);
            this.xssFilterConfiguration(app);
            this.hpkpConfiguration(app);
            this.hstsConfiguration(app);
            this.referrerPolicyConfiguration(app);
        }
    }

    protected hppConfiguration(app) {
        // Suppression des doublons de paramètres GET
        if (checkSecurityConfiguration("security.hpp", false,
                                       "HPP 'HTTP Parameter Pollution'", SecurityMiddleware.logger)) {
            app.use(hpp());
        }
    }

    protected ieNoOpenConfiguration(app) {

        if (checkSecurityConfiguration("security.ieNoOpen", false,
                                       "ienoopen 'IE, restrict untrusted HTML: ieNoOpen'", SecurityMiddleware.logger)) {
            // Pour IE8+: ajout le header X-Download-Options
            app.use(helmet.ieNoOpen());
        }
    }

    protected noSniffConfiguration(app) {

        if (checkSecurityConfiguration("security.noSniff", false,
                                       "noSniff 'Don't infer the MIME type: noSniff'", SecurityMiddleware.logger)) {
            // Pour IE8+: ajout le header X-Download-Options
            app.use(helmet.noSniff());
        }
    }

    protected cspConfiguration(app) {
        // Ajout des headers "content security" pour empêcher le chargement de scripts venant d'autres domaines
        if (checkSecurityConfiguration("security.csp", true, "CSP 'Content Security Policy'", SecurityMiddleware.logger)) {
            const directives: any = {
                // defaultSrc: Utils.config.getOrDefault("security.csp.defaultSrc", ["'self'", "'unsafe-inline'", "'unsafe-eval'"]),
                baseUri: Utils.config.getOrDefault("security.csp.baseUri", [ "'self'" ]),
                childSrc: Utils.config.getOrDefault("security.csp.childSrc", [ "'self'" ]),
                connectSrc: Utils.config.getOrDefault("security.csp.connectSrc", [ "'self'" ]),
                fontSrc: Utils.config.getOrDefault("security.csp.fontSrc", [ "'self'" ]),
                formAction: Utils.config.getOrDefault("security.csp.formAction", [ "'self'" ]),
                frameAncestors: Utils.config.getOrDefault("security.csp.frameAncestors", [ "'self'" ]),
                frameSrc: Utils.config.getOrDefault("security.csp.frameSrc", [ "'self'" ]), // deprecated gestion ancien navigateur
                imgSrc: Utils.config.getOrDefault("security.csp.imgSrc", [ "'self'" ]),
                manifestSrc: Utils.config.getOrDefault("security.csp.manifestSrc", [ "'self'" ]),
                mediaSrc: Utils.config.getOrDefault("security.csp.mediaSrc", [ "'self'" ]),
                objectSrc: Utils.config.getOrDefault("security.csp.objectSrc", [ "'self'" ]),
                // todo deal with missing directives
                // reflectedXss: Utils.config.getOrDefault("security.csp.reflectedXss", "block"),
                // todo create post route to report policy failures
                // reportUri: Utils.config.getOrDefault("security.csp.reportUri", ""),
                scriptSrc: Utils.config.getOrDefault("security.csp.scriptSrc", [ "'self'", "'unsafe-inline'", "'unsafe-eval'" ]),
                styleSrc: Utils.config.getOrDefault("security.csp.styleSrc", [ "'self'", "'unsafe-inline'" ]),
            };
            const sandbox = Utils.config.getOrDefault("security.csp.sandbox", false); // TODO A traiter spécifiquement
            if (sandbox) {
                directives.sandbox = sandbox;
            }
            const pluginTypes = Utils.config.getOrDefault("security.csp.pluginTypes", false);
            if (pluginTypes) {
                directives.pluginTypes = pluginTypes;
            }
            const blockAllMixedContent = Utils.config.getOrDefault("security.csp.blockAllMixedContent", false);
            if (blockAllMixedContent) {
                directives.blockAllMixedContent = blockAllMixedContent;
            }
            const upgradeInsecureRequests = Utils.config.getOrDefault("security.csp.upgradeInsecureRequests", false);
            if (upgradeInsecureRequests) {
                directives.upgradeInsecureRequests = upgradeInsecureRequests;
            }
            app.use(helmet.contentSecurityPolicy({
                directives,
                disableAndroid: Utils.config.getOrDefault("security.csp.disableAndroid", false),
                reportOnly: Utils.config.getOrDefault("security.csp.reportOnly", false),
                setAllHeaders: Utils.config.getOrDefault("security.csp.setAllHeaders", true),
            }));
        }
    }

    protected referrerPolicyConfiguration(app) {
        app.use(helmet.referrerPolicy({
            policy: Utils.config.getOrDefault("security.csp.referrer", "origin-when-cross-origin"),
        }));
    }

    protected frameguardConfiguration(app) {
        // Pour empêcher la mise en itiframe
        if (checkSecurityConfiguration("security.frameguard", true, "frameguard", SecurityMiddleware.logger)) {
            const action = Utils.config.getOrDefault("security.frameguard.action", "deny");
            let domain = undefined;

            if (action === "allow-from") {
                domain = Utils.config.getOrDefault("security.frameguard.domain", "'self'");
            }

            app.use(helmet.frameguard({
                action,
                domain,
            }));
        }
    }

    protected xssFilterConfiguration(app) {

        if (checkSecurityConfiguration("security.xss", true, "XssFilter 'Cross-site scripting Filter'", SecurityMiddleware.logger)) {
            // Ajoute le header X-XSS-Protection pour essayer de protéger contre des attaques XSS simples
            // This has some security problems for old IE!
            app.use(helmet.xssFilter({ setOnOldIE: Utils.config.getOrDefault("security.xss.setOnOldIE", true) }));
        }
    }

    protected hpkpConfiguration(app) {
        // Ajoute les headers HTTP Public Key Pinning pour sécuriser les connexions SSL
        if (checkSecurityConfiguration("security.hpkp", true, "HPKP 'HTTP Public Key Pinning'", SecurityMiddleware.logger)) {
            app.use(helmet.hpkp({
                maxAge: Utils.config.getOrDefault("security.hpkp.maxAge", 7776000000),
                sha256s: Utils.config.get("security.hpkp.sha256s"),
                includeSubdomains: Utils.config.getOrDefault("security.hpkp.includeSubdomains", true),
                reportUri: Utils.config.getOrDefault("security.hpkp.reportUri", null),
                reportOnly: Utils.config.getOrDefault("security.hpkp.reportOnly", false),
            }));
        }
    }

    protected hstsConfiguration(app) {
        if (checkSecurityConfiguration("security.hsts", true, "HSTS 'HTTP Strict-Transport-Security'", SecurityMiddleware.logger)) {
            // Ajoute le header Strict-Transport-Security pour demander au navigateur client un accès au site en https
            app.use(helmet.hsts({
                // Must be at least 18 weeks to be approved by Google
                maxAge: Utils.config.getOrDefault("security.hsts.maxAge", 10886400000),
                // Must be enabled to be approved by Google
                includeSubDomains: Utils.config.getOrDefault("security.hsts.includeSubDomains", true),
                preload: Utils.config.getOrDefault("security.hsts.preload", false),
            }));
        }
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      CsrfMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
import * as _ from "lodash";
import director = require("director");

export class CsrfMiddleware extends AbstractHornetMiddleware {
    protected static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.CsrfMiddleware");
    static HEADER_CSRF_NAME = "x-csrf-token";
    static CSRF_SESSION_KEY = "security.csrf";

    public insertMiddleware(app) {
        if (isSecurityEnabled(isEnvProduction, CsrfMiddleware.logger)) {
            this.csrfConfiguration(app);
        }
    }

    protected csrfConfiguration(app) {
        if (checkSecurityConfiguration("security.csrf", true, "CSRF 'Cross-Site Request Forgery'", CsrfMiddleware.logger)) {
            app.use(CsrfMiddleware.middleware);
        }
    }

    /**
     * Retourne un nouveau token aléatoire
     * @return {string}
     */
    static generateToken(): string {
        const newToken = Math.random().toString(36).slice(2);
        CsrfMiddleware.logger.trace("Génération d'un token CSRF:", newToken);
        return newToken;
    }

    /**
     * Middleware express pour sécuriser les verbs HTTP PUT, POST, PATCH et DELETE d'attaques CSRF
     * @param req
     * @param resrouter
     * @param next
     */
    static middleware(req, res: director.DirectorResponse, next) {
        if (req.method === "PUT" || req.method === "POST" || req.method === "PATCH" || req.method === "DELETE") {
            let incomingCsrf = req.headers[ CsrfMiddleware.HEADER_CSRF_NAME ];
            if (_.isUndefined(incomingCsrf)) {
                CsrfMiddleware.logger.trace(CsrfMiddleware.HEADER_CSRF_NAME, "non present, recherche dans le body de la requête");
                incomingCsrf = req.body && req.body[ CsrfMiddleware.HEADER_CSRF_NAME ];
            }
            const sessionCsrf = req.getSession().getAttribute(CsrfMiddleware.CSRF_SESSION_KEY);

            const valid = CsrfMiddleware.isTokenValid(incomingCsrf, sessionCsrf);
            if (valid) {
                // Le token est correcte, l'accès est autorisé
                next();
            } else {
                CsrfMiddleware.logger.debug("Csrf mismatch, retourning 417 status");

                res.status(417);
                res.end();
            }

        } else {
            // Pas de sécurité csrf sur ce verb HTTP.
            // On récupère le token courant en session, généré si absent, puis on l'insère dans le CLS
            let token = req.getSession().getAttribute(CsrfMiddleware.CSRF_SESSION_KEY);
            if (token != null) {
                CsrfMiddleware.logger.debug("Token CSRF already exists in session");
            } else {
                token = CsrfMiddleware.generateToken();
                req.getSession().setAttribute(CsrfMiddleware.CSRF_SESSION_KEY, token);
            }
            Utils.setCls("hornet.csrf", token);

            next();
        }
    }

    /**
     * Détermine si le token envoyé correspond à celui stocké en session
     * @param incomingCsrf
     * @param sessionCsrf
     * @return {boolean}
     */
    static isTokenValid(incomingCsrf: string, sessionCsrf: string) {
        CsrfMiddleware.logger.trace("incomingCsrf =", incomingCsrf, "sessionCsrf =", sessionCsrf);

        return incomingCsrf === sessionCsrf;
    }

}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      InternationalizationMiddleware                                                 //
// ------------------------------------------------------------------------------------------------------------------- //

import { II18n, AbstractI18nLoader }  from "hornet-js-core/src/i18n/abstract-i18n-loader";
import { CookieManager }  from "hornet-js-core/src/session/cookie-manager";

export class InternationalizationMiddleware extends AbstractHornetMiddleware {

    protected static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.InternationalizationMiddleware");

    constructor(config?: ServerConfiguration) {

        super((req, res, next: Function) => {
            const appConfig = this.config || AbstractHornetMiddleware.APP_CONFIG;

            const isI18nInSession: boolean = req.session && req.session.i18n;
            let localeI18n: II18n = (isI18nInSession) ? req.session.i18n : Utils.config.getOrDefault("localeI18n", {});

            if (!isI18nInSession) {
                const cookLocaleI18n = CookieManager.getCookie(req, "internationalization");
                if (cookLocaleI18n !== undefined) {
                    const shortLang = cookLocaleI18n.split("-");
                    localeI18n = { locale: cookLocaleI18n, lang: shortLang[ 1 ] };
                }
            }

            if (appConfig.internationalization instanceof AbstractI18nLoader) {
                Utils.setCls("hornet.internationalization", appConfig.internationalization.getMessages(localeI18n));
            }

            if (!isI18nInSession) {
                InternationalizationMiddleware.logger.trace("InternationalizationMiddleware :  Mise en session de la locale "
                    + localeI18n.locale);
                req.session.i18n = localeI18n;
            }

            next();
        },    null, config);
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      ChangeI18nLocaleMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
export class ChangeI18nLocaleMiddleware extends AbstractHornetMiddleware {

    protected static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.ChangeI18nLocaleMiddleware");

    constructor() {
        const appConfig = AbstractHornetMiddleware.APP_CONFIG;

        if (!Utils.appSharedProps.get("listLanguage") && appConfig.internationalization) {
            Utils.appSharedProps.set("listLanguage", appConfig.internationalization.getLocales());
        }

        super((req, res, next: Function) => {
            if (_.some(appConfig.internationalization.getLocales(), { locale: req.params.i18n })) {

                ChangeI18nLocaleMiddleware.logger.trace("ChangeI18nLocaleMiddleware :  Changement de la locale " + req.params.i18n);
                const shortLang = req.params.i18n.split("-");
                req.session.i18n = { locale: req.params.i18n, lang: shortLang[ 1 ] };
                const i18n = appConfig.internationalization.getMessages(req.session.i18n);
                Utils.setCls("hornet.internationalization", i18n);
                CookieManager.setCookie(res, "internationalization", req.params.i18n);
                res.type("application/json");
                res.status(200).send(i18n);
                res.end();
            } else {
                ChangeI18nLocaleMiddleware.logger.trace("ChangeI18nLocaleMiddleware :  La locale demandée "
                    + req.params.i18n + "n'existe pas");
                const err = new TechnicalError("ERR_TECH_UNKNOWN", {
                    errorMessage: "La locale '" + req.params.i18n + "' n\'existe pas",
                    httpStatus: 200,
                });
                res.json(NodeApiResultBuilder.buildError(err));
                res.end();
            }
        });

        this.prefix = "/changeLanguage/:i18n";
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      SetExpandedLayoutMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
export class SetExpandedLayoutMiddleware extends AbstractHornetMiddleware {

    protected static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.SetExpandedLayoutMiddleware");

    constructor() {

        super((req, res, next: Function) => {
            SetExpandedLayoutMiddleware.logger.trace("SetLayoutMiddleware : set isExpandedLayout appSharedProps with value:",
                                                     req.body.isExpandedLayout);
            Utils.appSharedProps.set("isExpandedLayout", req.body.isExpandedLayout);
            res.type("application/json");
            res.status(200).send({ isExpandedLayout: req.body.isExpandedLayout });
            res.end();
        });

        this.prefix = "/setExpandedLayout";
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      IsExpandedLayoutMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
export class IsExpandedLayoutMiddleware extends AbstractHornetMiddleware {

    protected static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.IsExpandedLayoutMiddleware");

    constructor() {

        super((req, res, next: Function) => {
            const isExpandedLayout = Utils.appSharedProps.get("isExpandedLayout");
            IsExpandedLayoutMiddleware.logger.trace("IsExpandedLayoutMiddleware : get isExpandedLayout appSharedProps: ", isExpandedLayout);
            res.type("application/json");
            res.set("Cache-Control", "no-cache");
            res.status(200).send({ isExpandedLayout });
            res.end();
        });

        this.prefix = "/isExpandedLayout";
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      SetExpandedLayoutMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
export class wakeUpNodeSessionMiddleware extends AbstractHornetMiddleware {

    protected static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.wakeUpNodeSessionMiddleware");

    constructor() {

        super((req, res, next: Function) => {
            wakeUpNodeSessionMiddleware.logger.trace("sollicitation du nodeJs suite à notification fin de session node");
            res.type("application/json");
            res.set("Cache-Control", "no-cache");
            res.status(200).send({});
            res.end();
        });

        this.prefix = "/wakeUpNodeSession";
    }
}


// ------------------------------------------------------------------------------------------------------------------- //
//                                      RouterServerMiddleware                                                         //
// ------------------------------------------------------------------------------------------------------------------- //
import { RouterServer }  from "hornet-js-core/src/routes/router-server";

export class RouterServerMiddleware extends AbstractHornetMiddleware {
    protected router: RouterServer;

    constructor(config?: ServerConfiguration) {
        super(null, null, config);
        const appConfig = this.config || AbstractHornetMiddleware.APP_CONFIG;
        this.router = new RouterServer(appConfig.defaultRoutesClass,
                                       appConfig.routesLoaderfn,
                                       appConfig.routesLoaderPaths,
                                       appConfig.routesDataContext);
    }

    public insertMiddleware(app) {
        app.use(this.router.pageMiddleware());
        app.use(Utils.config.getOrDefault("fullSpa.name",
                                          AbstractHornetMiddleware.APP_CONFIG.routesDataContext),
                this.router.dataMiddleware());
    }
}

export class RouterServerSubMiddleware extends AbstractHornetSubMiddleware {

    private router: RouterServer;

    constructor(config: ServerConfiguration) {
        super(null, null, config);
        const appConfig = this.config || AbstractHornetMiddleware.APP_CONFIG;
        this.router = new RouterServer(appConfig.defaultRoutesClass,
                                       appConfig.routesLoaderfn,
                                       appConfig.routesLoaderPaths,
                                       appConfig.routesDataContext);
    }

    public insertRouterMiddleware(router: express.Router) {
        router.use(this.router.pageMiddleware());
        router.use(Utils.config.getOrDefault("fullSpa.name", (this.config || AbstractHornetMiddleware.APP_CONFIG).routesDataContext),
                   this.router.dataMiddleware());
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      UserAccessSecurityMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
import { AuthUtils } from "hornet-js-utils/src/authentication-utils";
import { SecurityError } from "hornet-js-utils/src/exception/security-error";
import { NotFoundError } from "hornet-js-utils/src/exception/not-found-error";

export class UserAccessSecurityMiddleware extends AbstractHornetMiddleware {
    protected static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.UserAccessSecurityMiddleware");

    constructor() {
        super((req, res, next) => {
            const routesAuthorization = Utils.getCls("hornet.routeAuthorization");

            if (!AuthUtils.isAllowed(req.user, routesAuthorization)) {
                let e: TechnicalError;
                if (isEnvProduction) {
                    e = new NotFoundError();
                }
                e = new SecurityError();
                UserAccessSecurityMiddleware.logger.trace("Tentative d'accès à une route non autorisée", req.url, e.reportId);
                throw e;
            }
            next();
        });
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      MenuConfigMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
export class MenuConfigMiddleware extends AbstractHornetMiddleware {
    constructor() {
        super((req, res, next) => {
            Utils.setCls("hornet.menuConfig", AbstractHornetMiddleware.APP_CONFIG.menuConfig);
            next();
        });
    }
}

// ------------------------------------------------------------------------------------------------------------------- //
//                                      DataRenderingMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
import { RouteInfos, DataRouteInfos }  from "hornet-js-core/src/routes/abstract-routes";
import { AsyncExecutor }  from "hornet-js-core/src/executor/async-executor";
import { AsyncElement }  from "hornet-js-core/src/executor/async-element";
import { NodeApiResultBuilder, NodeApiResult }  from "hornet-js-core/src/services/service-api-results";
import { ValidationError } from "hornet-js-utils/src/exception/validation-error";
import { HornetResult }  from "hornet-js-core/src/result/hornet-result";
import { ResultStream }  from "hornet-js-core/src/result/result-stream";
import { ResultJSON }  from "hornet-js-core/src/result/result-json";

export class DataRenderingMiddleware extends AbstractHornetMiddleware {
    protected static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.DataRenderingMiddleware");

    constructor() {
        super((req: Request, res: Response, next: Function) => {
            try {
                const routeInfos: RouteInfos = Utils.getCls("hornet.routeInfos");

                // route de type 'DATA' uniquement
                if (Utils.getCls("hornet.routeType") === RouteType.DATA) {

                    const dataRouteInfos = routeInfos as DataRouteInfos;

                    if (!dataRouteInfos) {
                        const mess = "DataRouteInfos inexistant pour l'url : " + req.originalUrl;
                        DataRenderingMiddleware.logger.warn(mess);
                        throw new TechnicalError("ERR_TECH_UNKNOWN", { errorMessage: mess, httpStatus: 200 });

                    } else {

                        const executor = new AsyncExecutor();
                        executor.addElement(new AsyncElement((next: (err?: any, data?: any) => void) => {
                            Timer.startTimer(Timer.TIMER_ACTION, Timer.TIMER_SERVER_HTTP);
                            const action = new (dataRouteInfos.getAction())();
                            action.req = req;
                            action.res = res;
                            action.attributes = routeInfos.getAttributes();
                            const actionService = dataRouteInfos.getService();
                            if (actionService) {
                                if (!(actionService as any).prototype) {
                                    action.service = actionService;
                                } else {
                                    DataRenderingMiddleware.logger.deprecated("Les services doivent être instanciés afin de pouvoir être utilisés par le composant DataRenderingMiddleware. Les services non instanciés ne seront bientôt plus supportés. Voir l'utilisation de l'injector avec un scope SINGLETON par exemple ou l'instanciation dans la déclaration de vos routes");
                                    action.service = new (actionService as Class<any>)();
                                }
                            }

                            const validator = action.getDataValidator();
                            if (validator) {
                                const data = _.cloneDeep(action.getPayload());

                                const validationRes = validator.validate(data);

                                if (!validationRes.valid) {
                                    DataRenderingMiddleware.logger.warn("Données invalides (la validation aurait dû être effectuée côté client) : ", validationRes.errors);
                                    throw new ValidationError();
                                }
                            }

                            const exec: Promise<any> = action.execute();

                            exec.then((result: any | HornetResult) => {
                                Timer.startTimer(Timer.TIMER_SERVER_HTTP, Timer.TIMER_ACTION);
                                const newResult: HornetResult = (result instanceof HornetResult) ? result : new ResultJSON({ data: result });
                                if (!(newResult instanceof ResultStream)) {
                                    res.status(newResult.status);
                                }
                                return newResult.manageResponse(res, req);
                            }).then((send) => {
                                Timer.stopTimer(Timer.TIMER_SERVER_HTTP);
                                Timer.stopTimer(Timer.TIMER_REQUEST);
                                Timer.logFinally(req.originalUrl, res.statusCode);
                                if (send) {
                                    res.end();
                                }
                            }).catch((error) => {
                                Timer.startTimer(Timer.TIMER_SERVER_HTTP, Timer.TIMER_ACTION);
                                DataRenderingMiddleware.logger.error("Erreur de service..." + error);
                                next(error);
                            });
                        }));

                        executor.on("end", (err) => {
                            if (err) {
                                next(err);
                            }
                        });
                        executor.execute();
                    }
                }

            } catch (e) {
                next(e);
            }
        });
    }
}

export class DataRenderingSubMiddleware extends AbstractHornetSubMiddleware {
    private static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.DataRenderingMiddleware");

    constructor() {
        super((req: Request, res: Response, next: Function) => {
            try {
                const routeInfos: RouteInfos = Utils.getCls("hornet.routeInfos");

                // route de type 'DATA' uniquement
                if (Utils.getCls("hornet.routeType") === RouteType.DATA) {

                    const dataRouteInfos = routeInfos as DataRouteInfos;

                    if (!dataRouteInfos) {
                        const mess = "DataRouteInfos inexistant pour l'url : " + req.originalUrl;
                        DataRenderingSubMiddleware.logger.warn(mess);
                        throw new TechnicalError("ERR_TECH_UNKNOWN", { errorMessage: mess, httpStatus: 200 });

                    } else {

                        const executor = new AsyncExecutor();
                        executor.addElement(new AsyncElement((next: (err?: any, data?: any) => void) => {
                            Timer.startTimer(Timer.TIMER_ACTION, Timer.TIMER_SERVER_HTTP);
                            const action = new (dataRouteInfos.getAction())();
                            action.req = req;
                            action.res = res;
                            action.attributes = routeInfos.getAttributes();
                            const actionService = dataRouteInfos.getService();
                            if (actionService) {
                                if (!(actionService as any).prototype) {
                                    action.service = actionService;
                                } else {
                                    DataRenderingSubMiddleware.logger.deprecated("Les services doivent être instanciés afin de pouvoir être utilisés par le composant DataRenderingSubMiddleware. Les services non instanciés ne seront bientôt plus supportés. Voir l'utilisation de l'injector avec un scope SINGLETON par exemple ou l'instanciation dans la déclaration de vos routes");
                                    action.service = new (actionService as Class<any>)();
                                }
                            }

                            const validator = action.getDataValidator();
                            if (validator) {
                                const data = _.cloneDeep(action.getPayload());

                                const validationRes = validator.validate(data);

                                if (!validationRes.valid) {
                                    DataRenderingSubMiddleware.logger.warn(
                                        "Données invalides (la validation aurait dû être effectuée côté client) : ",
                                        validationRes.errors);
                                    throw new ValidationError();
                                }
                            }

                            const exec: Promise<any> = action.execute();

                            exec.then((result: any | HornetResult) => {
                                Timer.startTimer(Timer.TIMER_SERVER_HTTP, Timer.TIMER_ACTION);
                                const newResult: HornetResult = (result instanceof HornetResult)
                                    ? result
                                    : new ResultJSON({ data: result });
                                if (!(newResult instanceof ResultStream)) {
                                    res.status(newResult.status);
                                }
                                return newResult.manageResponse(res, req);
                            }).then((send) => {
                                Timer.stopTimer(Timer.TIMER_SERVER_HTTP);
                                Timer.stopTimer(Timer.TIMER_REQUEST);
                                Timer.logFinally(req.originalUrl, res.statusCode);
                                if (send) {
                                    res.end();
                                }
                            }).catch((error) => {
                                Timer.startTimer(Timer.TIMER_SERVER_HTTP, Timer.TIMER_ACTION);
                                DataRenderingSubMiddleware.logger.error("Erreur de service..." + error);
                                next(error);
                            });
                        }));

                        executor.on("end", (err) => {
                            if (err) {
                                next(err);
                            }
                        });
                        executor.execute();
                    }
                }

            } catch (e) {
                next(e);
            }
        });
    }
}


import { BaseError } from "hornet-js-utils/src/exception/base-error";
import { BusinessError } from "hornet-js-utils/src/exception/business-error";
import { TechnicalError } from "hornet-js-utils/src/exception/technical-error";
import { RequestHandler, Request, Response, ErrorRequestHandler } from "express";
import { ServiceRequest } from "../services/service-request";

// ------------------------------------------------------------------------------------------------------------------- //
//                                      UnmanagedDataErrorMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
export class UnmanagedDataErrorMiddleware extends AbstractHornetMiddleware {
    protected static logger: Logger = Utils.getLogger("hornet-js-core.middlewares.UnmanagedDataErrorMiddleware");

    constructor() {
        super((err, req, res, next: any) => {
            // route de type 'DATA' uniquement
            if (Utils.getCls("hornet.routeType") === RouteType.DATA) {
                sanitizeErrorThrownInDomain(err);

                if (!(err instanceof BaseError)) {
                    err = new TechnicalError(err.code || "ERR_TECH_UNKNOWN", { errorMessage: err.message }, err);
                }

                if (err instanceof TechnicalError) {
                    UnmanagedDataErrorMiddleware.logger.error("ERREUR technique [" + err.code + "] - reportId [" + err.reportId + "] : ", err);
                } else if (err instanceof BusinessError) {
                    UnmanagedDataErrorMiddleware.logger.error("ERREUR métier [" + err.code + "] - : ", err);
                } else {
                    UnmanagedDataErrorMiddleware.logger.error("ERREUR [" + err.code + "] - : ", err);
                }

                res.json(NodeApiResultBuilder.buildError(err, req && req.originalUrl));
                res.status(200);
                if (Utils.config.getOrDefault("server.rethrow", false)) {
                    if (err.status && typeof err.status === "number") {
                        res.status(err.status);
                    } else if (err.args && err.args.httpStatus && typeof err.args.httpStatus === "number") { // gestion avec les NodeApiError
                        res.status(err.args.httpStatus);
                    } else {
                        res.status(500);
                    }
                }
                Timer.stopTimer(Timer.TIMER_SERVER_HTTP);
                Timer.stopTimer(Timer.TIMER_REQUEST);
                Timer.logFinally(req.originalUrl, res.statusCode);
                res.end();
            } else {
                UnmanagedDataErrorMiddleware.logger.error("ERREUR technique [" + err.code + "] - reportId [" + err.reportId + "] : ", err);
                if (err.status && typeof err.status === "number") {
                    res.status(err.status);
                } else if (err.args && err.args.httpStatus && typeof err.args.httpStatus === "number") { // gestion avec les NodeApiError
                    res.status(err.args.httpStatus);
                } else {
                    res.status(500);
                }
                Timer.stopTimer(Timer.TIMER_REQUEST);
                Timer.logFinally(req.originalUrl, res.statusCode);
                res.end();
            }
        });
    }
}

export class AliveMiddleware extends AbstractHornetMiddleware {
    static APP_CONFIG: ServerConfiguration;
    protected prefix: string;
    protected middlewareFunction: RequestHandler;
    protected config: ServerConfiguration;

    /**
     * Constructeur
     *
     * @param middlewareFunction
     * @param prefix
     * @param config server configuration
     */
    constructor(middlewareFunction?: RequestHandler, prefix?: string, config?: ServerConfiguration) {
        super((req, res, next) => {
            res.status(204).end();
        },    prefix || "alive");
    }

    /**
     * Méthode appelée automatiquement lors de l'initialisation du serveur afin d'ajouter un middleware
     * @param app
     */
    public insertMiddleware(app: express.Express) {
        app.get(this.prefix || "alive", this.middlewareFunction);
    }
}

export const DEFAULT_HORNET_MIDDLEWARES: Array<Class<AbstractHornetMiddleware>> = [
    AliveMiddleware,

    HornetContextInitializerMiddleware,

    LoggerTIDMiddleware,
    SecurityMiddleware,
    WelcomePageRedirectMiddleware,
    WithoutSlashPageRedirectMiddleware,
    StaticNodeHttpHeaderMiddleware,
    StaticPathMiddleware,
    StaticPathErrorMiddleware,
    BodyParserJsonMiddleware,
    BodyParserUrlEncodedMiddleware,

    // MockManagerMiddleware,
    SessionMiddleware,
    InternationalizationMiddleware,
    ChangeI18nLocaleMiddleware,
    wakeUpNodeSessionMiddleware,
    LoggerUserMiddleware,
    CsrfMiddleware,
    MulterMiddleware,
    SetExpandedLayoutMiddleware,
    IsExpandedLayoutMiddleware,

    MenuConfigMiddleware,
    RouterServerMiddleware,
    UserAccessSecurityMiddleware,
    DataRenderingMiddleware,

    UnmanagedDataErrorMiddleware,
];

export const DEFAULT_HORNET_MODULE_MIDDLEWARES: Array<Class<AbstractHornetSubMiddleware>> = [
    HornetContextInitializerSubMiddleware,
    RouterServerSubMiddleware,
    DataRenderingSubMiddleware,
];


export class HornetMiddlewareList {

    public list = [];

    constructor(middlewares: Array<Class<AbstractHornetMiddleware>> = DEFAULT_HORNET_MIDDLEWARES) {
        middlewares.forEach((middleware) => {
            this.list.push(middleware);
        });
    }

    addBefore(newMiddleware: Class<AbstractHornetMiddleware>, middleware: Class<AbstractHornetMiddleware>) {
        const idx = this.list.indexOf(middleware);
        if (idx === -1) {
            throw new Error("Le middleware de base n'a pas été trouvé dans le tableau de middlewares " +
                ">> impossible d'insérer le nouveau middleware avant.");
        }
        this.list.splice(idx, 0, newMiddleware);
        return this;
    }

    addRouterBefore(router: HornetRouter, middleware: Class<AbstractHornetMiddleware>) {

        const idx = this.list.indexOf(middleware);
        if (idx === -1) {
            throw new Error("Le middleware de base n'a pas été trouvé dans le tableau de middlewares " +
                ">> impossible d'insérer le nouveau middleware avant.");
        }
        this.list.splice(idx, 0, router);
        return this;
    }

    addAfter(newMiddleware: Class<AbstractHornetMiddleware>, middleware: Class<AbstractHornetMiddleware>) {
        const idx = this.list.indexOf(middleware);
        if (idx === -1) {
            throw new Error("Le middleware de base n'a pas été trouvé dans le tableau de middlewares " +
                ">> impossible d'insérer le nouveau middleware après.");
        }
        this.list.splice(idx + 1, 0, newMiddleware);
        return this;
    }

    remove(middleware: Class<AbstractHornetMiddleware>) {
        const idx = this.list.indexOf(middleware);
        if (idx === -1) {
            throw new Error("Le middleware n'a pas été trouvé dans le tableau de middlewares " +
                ">> suppression impossible.");
        }
        this.list.splice(idx, 1);
        return this;
    }
}

export class HornetRouter {
    constructor(public prefix: string, public router: express.Router) {
    }
}
